@@ -140,6 +140,8 @@ private:
 private:
     static double getCpuFreq(model_t model);
 
+    static void deleteSids(sidBankMap_t &extraSidBanks);
+
 private:
     /**
      * IRQ trigger signal.
@@ -258,6 +260,8 @@ public:
     sidmemory& getMemInterface() { return mmu; }
 
     uint_least16_t getCia1TimerA() const { return cia1.getTimerA(); }
+
+    unsigned int installedSIDs() const;
 };
 
 void c64::interruptIRQ(bool state)
