@@ -147,26 +147,27 @@ int main(int, char* argv[])
     int handle=::open("/dev/dsp", O_WRONLY, 0);
     int format=AFMT_S16_LE;
     ioctl(handle, SNDCTL_DSP_SETFMT, &format);
-    int chn=1;
+    int chn=2;
     ioctl(handle, SNDCTL_DSP_CHANNELS, &chn);
     int sampleRate=SAMPLERATE;
     ioctl(handle, SNDCTL_DSP_SPEED, &sampleRate);
     int bufferSize;
     ioctl(handle, SNDCTL_DSP_GETBLKSIZE, &bufferSize);
 
-    uint_least32_t bufferSamples = static_cast<uint_least32_t>(bufferSize) / sizeof(short);
-
-    // Play
-    std::vector<short> buffer(bufferSamples);
+    // 48000/~1000000 * 5000 * 2
+    short buffer[512];
+    // Play for ~5 seconds
+    m_engine.initMixer(true);
     for (int i=0; i<1000; i++)
     {
-        uint_least32_t res = m_engine.play(&buffer.front(), bufferSamples);
-        if (!m_engine.isPlaying() || (res < bufferSamples))
+        int res = m_engine.play(5000);
+        if (res < 0)
         {
-            std::cerr <<  m_engine.error() << std::endl;
+            std::cerr << m_engine.error() << std::endl;
             break;
         }
-        ::write(handle, &buffer.front(), bufferSize);
+        unsigned int s = m_engine.mix(buffer, res);
+        ::write(handle, buffer, s*sizeof(short));
     }
 
     ::close(handle);
